@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
 our $DATE = '2015-06-16'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -751,7 +751,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.05 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-06-16.
+This document describes version 0.06 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-06-16.
 
 =head1 SYNOPSIS
 
@@ -775,6 +775,22 @@ This document describes version 0.05 of Perinci::CmdLine::Inline (from Perl dist
 
 B<EARLY DEVELOPMENT.>
 
+Sample startup overhead benchmark vs Perinci::CmdLine::Lite:
+
+                               Rate    run (lite) --version (lite) run (inline) --version (inline)   perl
+ run (lite)         13.697+-0.011/s            --           -60.8%       -79.1%             -81.5% -97.2%
+ --version (lite)   34.979+-0.048/s  155.38+-0.4%               --       -46.7%             -52.8% -92.9%
+ run (inline)        65.673+-0.09/s 379.46+-0.76%     87.75+-0.36%           --             -11.4% -86.7%
+ --version (inline)   74.13+-0.12/s 441.21+-0.98%    111.93+-0.45% 12.88+-0.24%                 -- -85.0%
+ perl                  493.4+-1.5/s     3502+-11%     1310.5+-4.6%  651.3+-2.5%        565.6+-2.3%     --
+ 
+ Average times:
+   perl              :     2.0268ms
+   --version (inline):    13.4898ms
+   run (inline)      :    15.2270ms
+   --version (lite)  :    28.5886ms
+   run (lite)        :    73.0087ms
+
 =head1 FUNCTIONS
 
 
